import AllHome from "@/components/home/AllHome";
import Banner from "@/components/home/Banner";
import BusinessSlider from "@/components/home/BusinessSlider";
import ChairmanMessage from "@/components/home/ChairmanMessage";
import VideoSection from "@/components/home/VideoSection";
import Divisions from "@/components/home/Divisions";
import NewsSlider from "@/components/home/NewsSlider";
import Testimonial from "@/components/home/Testimonial";
import WorkHard from "@/components/WorkHard";
import {getHomeApi} from "@/api/home";
import Brands from "@/components/home/Brands";



export async function metadata() {
    const apiValue = "home";
    const getHomeData = await getHomeApi(apiValue)
    const banner = getHomeData?.data?.sections?.find(
        (f) => f?.section_data?.template === "home_banner"
    );
    return {
        title: {
            default: `${getHomeData?.data?.page_data?.meta_title} | SA Group of Industries`,
        },
        description: `${getHomeData?.data?.page_data?.meta_description}`,
        openGraph: {
            title: `${getHomeData?.data?.page_data?.og_title}`,
            description: `${getHomeData?.data?.page_data?.og_description}`,
            images: [
                {
                    url: `${banner?.images?.list?.filter(f=>f?.video != 'on')?.[0]?.full_path}`,
                    alt: `${getHomeData?.data?.page_data?.meta_title}`,
                },
            ],
        },
    };
}


export default async function Home() {
    const page = "home";
    const getHomeData = await getHomeApi(page)

    //Refactor
    const banner = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_banner');
    const business = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_business');
    const brands = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_brands');
    const chairman = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_chairman');
    const video = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_video');
    const divisions = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_divisions');
    const work = getHomeData?.data?.sections?.find(f=>f?.section_data?.template === 'home_work_hard');
    const verticals = getHomeData?.feature_products;
    const news = getHomeData?.feature_news;
    const testimonial = getHomeData?.testimonial;


    return (
        <>
            <Banner data={banner}/>
            <BusinessSlider data={verticals} subtitle={business?.section_data?.subtitle}/>
            <Brands data={brands}/>
            <ChairmanMessage data={chairman}/>
            <VideoSection data={video}/>
            <Divisions data={divisions}/>
            <NewsSlider data={news}/>
            <Testimonial data={testimonial}/>
            <WorkHard data={work}/>
            {/*<AllHome/>*/}
        </>
    );
};


