'use client';
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import Link from 'next/link'
import {getContactApi} from "@/api/contact";
import {useEffect, useState} from "react";
import InnerBanner from "@/components/InnerBanner";
import Address from "@/components/Contact/Address";
import MapForm from "@/components/Contact/MapForm";
import WorkHard from "@/components/WorkHard";
import { ScrollTrigger } from "gsap/ScrollTrigger";
import { CSSPlugin, gsap } from "gsap";
import {SplitText} from "gsap/SplitText";

const MyComponent = () => {
    gsap.registerPlugin(ScrollTrigger, CSSPlugin);
    const [getContactData, setContactData] = useState(null);

    useEffect(() => {
        const fetchAboutData = async () => {
            const data = await getContactApi();
            setContactData(data);
        };

        fetchAboutData();
    }, []);

    const banner = getContactData?.data?.sections?.find(f=>f?.section_data?.template === 'inner_banner');
    const address = getContactData?.data?.sections?.find(f=>f?.section_data?.template === 'contact_address');
    const map = getContactData?.data?.sections?.find(f=>f?.section_data?.template === 'contact_map');
    const work = getContactData?.data?.sections?.find(f=>f?.section_data?.template === 'home_work_hard');

    //image reveal
    useEffect(() => {

        let reveal = gsap.utils.toArray(".reveal-img");
        reveal.forEach((cont) => {
            let img = cont.querySelector("img");
            let tl = gsap.timeline({
                scrollTrigger: {
                    trigger: cont,
                    toggleActions: "restart none none reset",
                    once: true,
                },
            });

            // clip-path reveal
            tl.from(
                img,
                1.5,
                {
                    clipPath: "inset(0% 0% 100% 0%)", // Start from bottom
                    ease: "power2.inOut",
                },
                {
                    clipPath: "inset(0% 0% 0% 0%)", // Move to top
                    ease: "power2.inOut",
                }
            );
        });


    }, [ getContactData]);
    //content animation
    useEffect(() => {
        let allAnim = document.querySelectorAll('.fade-up');
        allAnim.forEach((el, index) => {
            gsap.fromTo(el, {
                autoAlpha: 0,
                y: 100,
                ease: "none",
            }, {
                y: 0,
                autoAlpha: 1,
                ease: "power2",
                duration: 1.5,
                scrollTrigger: {
                    id: `${index + 1}`,
                    trigger: el,
                    start: 'top center+=150',
                    toggleActions: 'play none none reverse',
                }
            })
        })
        return (() => {
            allAnim = ''
        })
    }, [ getContactData]);
    //text animation
    useEffect(() => {
        // ScrollTrigger.refresh();
        // document.fonts.ready.then(() => {

        gsap.utils.toArray('.split-up').forEach((item, i) => {
            const parentSplit = new SplitText(item, {
                wordsClass: "split-parent",
                type: "words",
                reduceWhiteSpace: false
            })
            const childSplit = new SplitText(item, {
                type: "words",
                wordsClass: "split-child",
                reduceWhiteSpace: false
            })

            const tl = gsap.timeline()

            childSplit.words.forEach(i => {

                i.parentNode.style.height = i.clientHeight + 'px'
                i.parentNode.style.overflow = 'hidden'
                // i.parentNode.style.background = 'red'
            })

            gsap.from(childSplit.words, {
                duration: 1,
                // delay: .02,
                yPercent: 150,
                alpha: 1,
                // ease: 'power4.out',
                // stagger: .06,
                scrollTrigger: {
                    trigger: item,
                    toggleActions: "restart none none reset",
                    // start: '-250',
                    // start: "top top",
                    end: `+ ${item.clientHeight}`,
                    // markers: true
                    once: true,
                }
            })
        });                          // do stuff

        // })

    }, [getContactData]);

    return (
        <>
            <InnerBanner title={banner?.section_data?.subtitle} img={banner?.images?.list?.[0]?.full_path} data={getContactData} color={'#ffffff'}/>
            <Address data={address}/>
            <MapForm data={map}/>
            <WorkHard data={work}/>
        </>
    );
};



export default MyComponent;
