'use client';

import { useForm } from 'react-hook-form';
import Button from '@/components/Button';
import { Form } from "react-bootstrap";
import { toast } from "react-toastify";
import axios from "axios";
import { useEffect, useState } from "react";

const ContactForm = ({ setIsSubmitting }) => {
    const { register, handleSubmit, formState, reset } = useForm({ mode: 'all' });
    const { errors } = formState;

    //--- form submit
    const success = (msg) =>
        toast.success(msg, {
            position: "top-right",
            autoClose: 4000,
            closeOnClick: true,
            progress: undefined,
        });

    const error = (msg) =>
        toast.error(msg, {
            position: "top-right",
            autoClose: 4000,
            closeOnClick: true,
            progress: undefined,
        });

    const onSubmit = async (data) => {
        setIsSubmitting(true); // Show spinner
        try {
            const formData = new FormData();
            formData.append('name', data?.name);
            formData.append('email', data?.email);
            formData.append('phone', data?.phone);
            formData.append('message', data?.message);
            formData.append('form_id', 'contact-form');

            const response = await axios.post('https://bestinbd.com/projects/web/2309SAG/api/post-req-data/form-submit', formData);

            if (response.status === 200) {
                success('Form submitted successfully');
                reset(); // Reset form fields
            } else {
                error('Failed to submit form. Please try again later.');
            }
        } catch (err) {
            error('Failed to submit form. Please try again later.');
        } finally {
            setIsSubmitting(false); // Hide spinner
        }
    };


    return (
        <Form onSubmit={handleSubmit(onSubmit)} className={'fade-up'}>
            <div className="form-group d-flex flex-column">
                <Form.Control
                    className={errors?.name ? 'has-error form-control-lg' : 'form-control-lg'}
                    {...register("name", {
                        required: 'Please enter your Name',
                        pattern: {
                            value: /^[A-Za-z ]+$/,
                            message: 'Name must contain only letters',
                        },
                    })}
                    type="text" placeholder="Enter your full name*" />
                {errors.name && <span className="error-message">{errors.name.message}</span>}
            </div>

            <div className="form-group d-flex flex-column">
                <Form.Control
                    className={errors?.phone ? 'has-error form-control-lg' : 'form-control-lg'}
                    {...register("phone", {
                        required: 'Please enter your phone number',
                        pattern: {
                            value: /^01[0-9]{9}$/,
                            message: 'Please enter a valid 11 digit phone number',
                        },
                    })}
                    type="number" placeholder="Enter your phone number*" />
                {errors.phone && <span className="error-message">{errors.phone.message}</span>}
            </div>

            <div className="form-group d-flex flex-column">
                <Form.Control
                    className={errors?.email ? 'has-error form-control-lg' : 'form-control-lg'}
                    {...register("email", {
                        required: 'Please enter your email',
                        pattern: {
                            value: /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,}$/i,
                            message: 'Please enter a valid email address',
                        },
                    })}
                    type="email" placeholder="Enter your email address*" />
                {errors.email && <span className="error-message">{errors.email.message}</span>}
            </div>

            <div className="form-group d-flex flex-column">
                <textarea
                    className={'textarea form-control form-control-lg'}

                    placeholder={'Enter your message*'} />
                {/*{errors.message && <span className="error-message">{errors.message.message}</span>}*/}
            </div>

            <div className="button" onClick={handleSubmit(onSubmit)}>
                <Button
                    type="submit"
                    text="Submit"
                    background="#ffffff"
                    color="#137EC3"
                    svgColor="#137EC3"
                    margin="30px 0 0"
                    width={'max-content'}
                />
            </div>
        </Form>
    );
};

export default ContactForm;
