"use client";
import styled from "styled-components";
import {Container, Row, Col, Form} from "react-bootstrap";
import Link from 'next/link'
import Title from "@/components/Title";
import Image from "next/image";
import Map from "@/public/images/dynamic/contact/map.jpg";
import Button from "@/components/Button";
import {hover} from "@/styles/globalStyleVars";
import ContactForm from "@/components/Contact/ContactForm";
import {useEffect, useState} from "react";
import {Loading} from "@/components/Loading";

const MyComponent = ({data}) => {
    const [isSubmitting, setIsSubmitting] = useState(false); // State to manage loading spinner

    return (
        <StyledComponent className={'pt-120 pb-120'}>
            <Container>
                <Title text={data?.section_data?.subtitle} color={'#ffffff'} margin={'0 0 40px'} />
                <Row>
                    <Col md={6} className={'form'}>
                        <div className="form__wrapper">
                            <ContactForm setIsSubmitting={setIsSubmitting} /> {/* Pass setIsSubmitting to ContactForm */}
                        </div>
                    </Col>
                    <Col md={{ offset: 1, span: 5 }} className={'map fade-up'}>
                        <a href={`https://www.google.com/maps?q=${data?.images?.list?.[0]?.short_desc}`} target={'_blank'}>
                            <div className="map__wrapper">
                                <Image src={data?.images?.list?.[0]?.full_path} alt={'map'} objectFit={'cover'} layout={'fill'} />
                            </div>
                        </a>
                    </Col>
                </Row>
            </Container>
            {isSubmitting && <Loading />} {/* Conditionally render loading spinner */}
        </StyledComponent>
    );
};

const StyledComponent = styled.section`
  position: relative;
  overflow: hidden;
    background-color: rgba(44, 126, 195, 0.9);
  .form{
    &__wrapper{
      form{
        .from-group {
          margin-bottom: 30px;
          gap: 30px;
          &:nth-last-child(1) {
            margin-bottom: 0;
          }
        }
        .form-control {
          background-color: transparent;
          border: none;
          border-bottom: 1px solid rgba(255 , 255 , 255 , .5);
          padding-left: 0;
          height: 34px;
          color: #ffffff;
          text-indent: 0;
          font-size: 16px;
          &::placeholder {
            font-size: 16px;
            line-height: 20px;
            color: rgba(255 , 255 , 255 , .75);
          }

          &:focus{
            border-bottom: 1px solid #ffffff;
          }
        }
          
          .error-message{
              font-size: 12px;
              line-height: 16px;
              color: #1C0600;
          }

        input:-webkit-autofill:active  {
          color : #ffffff !important;
          -webkit-text-fill-color: #ffffff !important;
          -webkit-box-shadow: 0 0 0 1000px transparent inset !important;
          -webkit-background-clip: text !important;
          background-clip: text !important;
        }

        .form-control-lg{
          padding: 0;
        }
        textarea {
          width: 100%;
          max-width: 100%;
          min-width: 100%;
          background-color: transparent;
          border-bottom: 1px solid rgba(0 , 0 , 0 , .5);
          //border-radius: 15px;
          height: 118px;
          max-height: 80px;
          min-height: 118px;
          color: #137EC3;;
          box-shadow: none;
          outline: none;
          padding-left: 15px;

          &::placeholder {
            font-size: 14px;
            color: rgba(0 , 0 , 0 , .5);

          }
        }

        .buttons{
          margin-top: 30px;
          gap: 30px;
        }

        @media(max-width: 767px){
          padding-right: 15px;
          .from-group{
            &.d-flex{
              flex-direction: column;
            }
          }

          .buttons{
            flex-direction: column;
            input{
              max-width: 100% !important;
            }

            .dc-btn{
              a{
                width: 100% !important;
              }
            }
          }
        }

          .form-control.has-error {
              border-color: #1C0600 !important;
          }
      }
    }
  }
  
  .map{
    &__wrapper{
      position: relative;
      overflow: hidden;
      border-radius: 0 50px;
      padding-top: calc(500 / 470 * 100%);
      img{
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        transform: scale(1);
        transition: transform 0.3s ease-in-out;
      }
      &:hover{
        img{
          transform: scale(1.03);
          transition: transform 0.3s ease-in-out;
        }
      }
    }
  }
  
  @media(max-width: 767px){
    .form{
      margin-bottom: 40px;
    }
  }
`;

export default MyComponent;
