"use client";
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import SubTitle from "@/components/SubTitle";
import Button from "@/components/Button";
import CountUp from "react-countup";
import VisibilitySensor from "react-visibility-sensor";
import reactHtmlParser from "react-html-parser";

const Overview = ({ subtitle, title, description, link, counter, subColor}) => {
    return (
        <StyledComponent className={'overview pt-120 pb-120'}>
            <Container>
                <Row>
                    <Col md={6} className={'overview__left'}>
                        <SubTitle text={ subtitle ? subtitle : 'Get to know us'} color={subColor}/>
                        <h4 className={'split-up'}>
                            {title ? reactHtmlParser(title) : 'S.A Group of Industries believes in the power of its brands to improve the quality\n' +
                                'of life and to provide supreme satisfaction to our consumers on a daily basis.'}
                        </h4>
                    </Col>
                    <Col md={{offset:1, span:5}}>
                        <p className={'split-up'}>
                            {
                                description ?
                                    reactHtmlParser(description)
                                    :
                                    'As our responsibilities grow with the size of our business, we recognize both local\n' +
                                    'and global factors. Adjudging the wider impact of our actions, it is true to accept\n' +
                                    'these actions are embedded in our values. And this is a fundamental part of S.A Group.\n' +
                                    '<br/> <br/>\n' +
                                    'The company’s motto is to serve the consumer’s need with good quality products on\n' +
                                    'reasonable prices. We take it as a promise and challenge to prove ourselves every day.\n' +
                                    'We are continuously raising the standard to keep our unfailing commitment to our\n' +
                                    'customers.'
                            }
                        </p>
                        {
                            link ?
                                <Button text={'Read More'} margin={'40px 0 0'} src={link}/>
                                :
                                ''
                        }
                    </Col>
                </Row>
                {
                    counter &&
                        <Row className={'counters'}>
                            {
                                counter?.length > 0 &&
                                counter?.map((e,i)=>{
                                    return(
                                        <Col md={3} className={'counters__single'} key={i}>
                                            <div className={'counters__single__data'}>
                                                <CountUp start={0} end={e?.data?.short_desc} duration={2}

                                                         separator=","
                                                         decimals={''}
                                                         decimal=","
                                                         suffix={'+'}
                                                >

                                                    {({countUpRef, start}) => (
                                                        <VisibilitySensor onChange={start}
                                                                          partialVisibility={{top: 0, bottom: 20}}
                                                                          delayedCall>

                                                            <h3 ref={countUpRef}></h3>


                                                        </VisibilitySensor>

                                                    )}

                                                </CountUp>
                                                <p>{reactHtmlParser(e?.data?.subtitle)}</p>
                                            </div>
                                        </Col>
                                    );
                                })
                            }

                        </Row>
                }
            </Container>
        </StyledComponent>
    );
};

const StyledComponent = styled.section`

    .counters{
      margin-top: 100px;
      &__single{
        &__data{
          border-left: 1px solid #2C7EC3;
          padding-left: 30px;
          padding-top: 20px;
          padding-bottom: 20px;
          h3{
            color: #2C7EC3;
            padding-bottom: 10px;
          }
          p{
            font-size: 14px;
            line-height: 20px;
            letter-spacing: 1.4px;
            text-transform: uppercase;
          }
        }
      }
      @media(max-width: 767px){
        margin-top: 40px;
        &__single{
          &__data{
            padding-left: 0;
            border-left: none;
            border-bottom: 1px solid #2C7EC3;
          }
          &:last-child{
            .counters__single__data{
              border-bottom: none;
            }
          }
        }
      }
    }
    
  @media(max-width: 767px){
    .overview__left{
      margin-bottom: 40px;
    }
  }
`;

export default Overview;
