"use client";
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import SubTitle from "@/components/SubTitle";
import Button from "@/components/Button";
import reactHtmlParser from "react-html-parser";
import OverviewPopup from "@/components/OverviewPopup";
import {useState} from "react";

const OverviewUpdated = ({ subtitle, title, description, link, subColor, id}) => {

    const [show, setShow] = useState(false);
    const [popupData, setPopupData] = useState({});

    const handleClose = () => setShow(false);
    const handleShow = (subtitle, title, description) => {
        setPopupData({subtitle, title, description});
        setShow(true);
    };

    return (
        <StyledComponent className={'overview pt-120 pb-120'} id={'overview'}>
            <Container>
                <Row>
                    <Col md={{offset:1, span: 10}} className={'overview__content'}>
                        <SubTitle text={subtitle ? subtitle : ''} color={subColor}/>
                        <h4 className={'split-up'}>
                            {title ? reactHtmlParser(title) : ''}
                        </h4>
                        <p className={'split-up'}>
                            {
                                description ?
                                    reactHtmlParser(description)
                                    :
                                    ''
                            }
                        </p>
                        <div className="btn" onClick={() => handleShow(subtitle, title, description)}>
                            <Button
                                text={'Read More'}
                                margin={'40px 0 0'}
                                color={'#137EC3'}
                                background={'#ffffff'}
                                svgColor={'#137EC3'}
                            />
                        </div>
                    </Col>
                </Row>
            </Container>
            <OverviewPopup show={show} data={popupData} handleClose={handleClose}/>
        </StyledComponent>
    );
};

const StyledComponent = styled.section`
    background-color: #137EC3;
    text-align: center;

    .overview{
        &__content{
            h4{
                color : #ffffff;
                margin-bottom: 40px;
            }
            p{
                color : #ffffff;
                display: -webkit-box;
                -webkit-box-orient: vertical;
                overflow: hidden;
                text-overflow: ellipsis;
                -webkit-line-clamp: 4; /* Limit to 5 lines */
                line-clamp: 4;
            }

            .dc-btn{
                a{
                    width: 100% !important;
                }
            }
        }
    }
    @media (max-width: 767px) {
        .overview__left {
            margin-bottom: 40px;
        }
    }
`;

export default OverviewUpdated;
