"use client";
import {useState, useEffect, useRef} from 'react';
import styled from "styled-components";
import {Col, Container, Row} from "react-bootstrap";
import FeaturePopup from "@/components/about/FeaturePopup";
import reactHtmlParser from "react-html-parser";
import {gsap} from "gsap";
const YourComponent = ({data}) => {
    const [expandedIndex, setExpandedIndex] = useState(0);
    const contentRefs = useRef([]);
    const handleAccordionClick = index => {
        if (expandedIndex === index) {
            // If the clicked item is already expanded, collapse it
            // setExpandedIndex(null);
            return;
        } else {
            // Expand the clicked item
            setExpandedIndex(index);
            animateContent(index);
        }
    };


    const [show, setShow] = useState(false);
    const [popupId, setPopupId] = useState()

    const handleClose = () => setShow(false);
    const handleShow = (e) => {
        setShow(true)
        setPopupId(e)
    }


    const animateContent = (index) => {
        const contentItems = contentRefs.current.filter((_, i) => i === index)[0].children;

        gsap.fromTo(
            contentItems,
            {
                y: '100%',
                opacity: 0,
                stagger: 0.3,
            },
            {
                y: 0,
                opacity: 1,
                stagger: 0.3,
                duration: 0.8,
                ease: 'ease-in-out',
            }
        );
    };


    return (
        <StyledComponent className={'accordion pt-120 pb-120 fade-up'}>
           <Container>
               <Row>
                   <Col md={12}>
                       <div className="accordion__items">
                           {
                               data?.posts?.list && data?.posts?.list?.length > 0 &&
                               data?.posts?.list?.map((e,i)=>{
                                   return(
                                       <div className={`accordion__items__single ${expandedIndex === i ? 'expanded' : ''}`}
                                            onClick={() => handleAccordionClick(i)}>
                                           <h6>
                                               {e?.data?.title}
                                           </h6>
                                           <svg xmlns="http://www.w3.org/2000/svg" width="21" height="21" viewBox="0 0 21 21">
                                               <g id="Group_21421" data-name="Group 21421" transform="translate(-1007.5 -1136)">
                                                   <line id="Line_3989" data-name="Line 3989" y2="20" transform="translate(1018 1136.5)" fill="none" stroke="#000" stroke-linecap="round" stroke-width="1"/>
                                                   <line id="Line_3990" data-name="Line 3990" y2="20" transform="translate(1028 1146.5) rotate(90)" fill="none" stroke="#000" stroke-linecap="round" stroke-width="1"/>
                                               </g>
                                           </svg>

                                           <div className="accordion__items__single__content" ref={(el) => (contentRefs.current[i] = el)}>
                                               <div className="svg">
                                                   <img src={e?.images?.[0]?.full_path}/>
                                               </div>
                                               <h3>{e?.data?.title}</h3>
                                               <p>
                                                   {
                                                       reactHtmlParser(e?.data?.description)
                                                   }
                                               </p>
                                               <div className="link" onClick={() => handleShow(e)}>
                                                   <p>Read More</p>
                                                   <svg xmlns="http://www.w3.org/2000/svg" width="20.5" height="5" viewBox="0 0 20.5 5">
                                                       <g id="Group_21340" data-name="Group 21340" transform="translate(-19 -670)">
                                                           <path id="Polygon_2" data-name="Polygon 2" d="M2.5,0,5,4H0Z" transform="translate(39.5 670) rotate(90)" fill="#5c5550"/>
                                                           <line id="Line_3986" data-name="Line 3986" x1="16" transform="translate(19.5 672.5)" fill="none" stroke="#5c5550" stroke-linecap="round" stroke-width="1"/>
                                                       </g>
                                                   </svg>
                                               </div>
                                           </div>

                                       </div>
                                   );
                               })
                           }
                       </div>
                   </Col>
               </Row>
           </Container>
            <FeaturePopup show={show} data={popupId} handleClose={handleClose}/>
        </StyledComponent>
    );
};


const StyledComponent = styled.section`
  
    .accordion{
      &__items{
        display: flex;
        justify-content: flex-end;
        &__single{
          width: 100px;
          height: 600px;
          display: flex;
          flex-direction: column-reverse;
          justify-content: space-between;
          align-items: center;
          gap:30px;
          border-left: 1px solid #5C5550;
          border-top: 1px solid #5C5550;
          border-bottom: 1px solid #5C5550;
          padding: 60px 0;
          cursor: pointer;
          transition: width 0.4s ease-in-out;
          position: relative;
          overflow: hidden;
          
          &:after{
            content: '';
            position: absolute;
            width: 100%;
            height: 0;
            bottom: 0;
            left: 0;
            background-color: #137EC3;
            transition: height 0.5s ease-in-out;
          }
          
          &:hover{
            h6{
              color: #ffffff !important;
              transition: 0.3s all ease-in-out;
            }
            svg{
              #Line_3989{
                stroke: #ffffff !important;
                transition: 0.3s all ease-in-out;
              }
              #Line_3990{
                stroke: #ffffff !important;
                transition: 0.3s all ease-in-out;
              }
            }
            &:after{
              height: 100%;
              transition: height 0.5s ease-in-out;
            }
          }
          
          &:last-child{
            border-right: 1px solid #5C5550;
          }
          h6{
            writing-mode: vertical-lr;
            transform: rotate(180deg);
            min-width: 20px;
            position: relative;
            z-index: 99;
          }
          
          svg{
            position: relative;
            z-index: 99;
          }
          
          &__content{
            display: none;
            opacity: 0;
            transition: opacity 0.4s ease-in-out;
          }
          
          &.expanded{
            width: calc(100vw - 300px);
            padding: 0;
            transition: width 0.4s ease-in-out;
            h6{
              display: none;
              opacity: 0;
            }
            
            svg{
              display: none;
              opacity: 0;
            }
            
            &:hover{
              &::after{
                display: none !important;
              }
            }
            
            .accordion__items__single__content{
              //display: flex !important;
              //flex-direction: column !important;
              //opacity: 1 !important;
              //height: 100%;
              //padding-left: 40px;
              //padding-right: 40px;
              //padding-top: 60px;
              //transition: opacity 1.5s ease-in-out;
              display: flex !important;
              flex-direction: column !important;
              opacity: 1 !important;
              height: 100%;
              padding-left: 40px;
              padding-right: 40px;
              padding-top: 60px;
              //transition: opacity 1.5s ease-in-out, transform 0.8s ease-in-out;
              //transform: translateY(100%); /* Initially move the content out of view */
              //animation: contentAnimation 0.8s ease-in-out forwards;

              //@keyframes contentAnimation {
              //  0% {
              //    transform: translateY(100%); /* Start from the bottom */
              //    opacity: 0;
              //  }
              //  100% {
              //    transform: translateY(0); /* Move to its position */
              //    opacity: 1;
              //  }
              //}
              .svg{
                display: flex;
                align-items: center;
                justify-content: center;
                height: 100px;
                width: 100px;
                border-radius: 50%;
                background: linear-gradient(180deg, rgba(19,126,195,1) 50%, rgba(47,191,255,1) 100%);
                margin-bottom: 40px;
                transition: opacity 0.5s ease;
              }
              
              h3{
                margin-bottom: 20px;
                color: #137EC3;
              }
              p{
                margin-bottom: 40px;
              }
              
              .link{
                display: flex;
                gap:15px;
                align-items: center;
                transition: all 0.3s ease;
                p{
                  margin-bottom: 0;
                }
                svg{
                  display: block;
                  opacity: 1;
                }
                
                &:hover{
                  gap:20px;
                  transition: all 0.3s ease;
                }
              }
            }
          }
        }
      }
      @media(max-width: 767px){
        &__items{
          flex-direction: column;
          &__single{
            width: calc(100%) !important;
            border-right: 1px solid #5C5550;
            height: 100px;
            padding: 20px;
            align-items: center;
            justify-content: space-between;
            flex-direction: row;
            border-top: none !important;
            
            &:first-child{
              border-top: 1px solid #5C5550 !important;
            }
            
            h6{
              writing-mode: unset;
              transform: unset;
            }
            
            &.expanded{
              width: 100%;
              height: 100%;
              transition: height 3s ease-in-out !important;
              .accordion__items__single__content{
                padding-top: 20px;
                padding-left: 15px;
                padding-right: 15px;
                padding-bottom: 20px;
                
                .svg{
                  height: 75px;
                  width: 75px;
                  margin-bottom: 20px;
                }
                
                p{
                  margin-bottom: 20px;
                }
              }
            }
          }
        }
      }
    }

`;

export default YourComponent;
