'use client';
import InnerBanner from "@/components/InnerBanner";
import OverviewUpdated from "@/components/OverviewUpdated";
import Directors from "@/components/about/Directors";
import Accordion from "@/components/about/Accordion";
import MissionVision from "@/components/about/MissionVision";
import {useEffect, useState} from "react";
import {getAboutApi} from "@/api/about";
import { ScrollTrigger } from "gsap/ScrollTrigger";
import { CSSPlugin, gsap } from "gsap";
import {SplitText} from "gsap/SplitText";

const MyComponent = () => {
    gsap.registerPlugin(ScrollTrigger, CSSPlugin);
    const [getAboutData, setAboutData] = useState(null);

    useEffect(() => {
        const fetchAboutData = async () => {
            const data = await getAboutApi();
            setAboutData(data);
        };

        fetchAboutData();
    }, []);

    // //Refactor
    const banner = getAboutData?.data?.sections?.find(f=>f?.section_data?.template === 'inner_banner');
    const overview = getAboutData?.data?.sections?.find(f=>f?.section_data?.template === 'overview');
    const accordion = getAboutData?.data?.sections?.find(f=>f?.section_data?.template === 'about_accordion');
    const mission = getAboutData?.data?.sections?.find(f=>f?.section_data?.template === 'about_mission_vision');
    const directors = getAboutData?.data?.sections?.find(f=>f?.section_data?.template === 'directors');


    //image reveal
    useEffect(() => {

        let reveal = gsap.utils.toArray(".reveal-img");
        reveal.forEach((cont) => {
            let img = cont.querySelector("img");
            let tl = gsap.timeline({
                scrollTrigger: {
                    trigger: cont,
                    toggleActions: "restart none none reset",
                    once: true,
                },
            });

            // clip-path reveal
            tl.from(
                img,
                1.5,
                {
                    clipPath: "inset(0% 0% 100% 0%)", // Start from bottom
                    ease: "power2.inOut",
                },
                {
                    clipPath: "inset(0% 0% 0% 0%)", // Move to top
                    ease: "power2.inOut",
                }
            );
        });


    }, [ getAboutData]);
    //content animation
    useEffect(() => {
        let allAnim = document.querySelectorAll('.fade-up');
        allAnim.forEach((el, index) => {
            gsap.fromTo(el, {
                autoAlpha: 0,
                y: 100,
                ease: "none",
            }, {
                y: 0,
                autoAlpha: 1,
                ease: "power2",
                duration: 1.5,
                scrollTrigger: {
                    id: `${index + 1}`,
                    trigger: el,
                    start: 'top center+=150',
                    toggleActions: 'play none none reverse',
                }
            })
        })
        return (() => {
            allAnim = ''
        })
    }, [ getAboutData])
    //text animation
    useEffect(() => {
        // ScrollTrigger.refresh();
        // document.fonts.ready.then(() => {

        gsap.utils.toArray('.split-up').forEach((item, i) => {
            const parentSplit = new SplitText(item, {
                wordsClass: "split-parent",
                type: "words",
                reduceWhiteSpace: false
            })
            const childSplit = new SplitText(item, {
                type: "words",
                wordsClass: "split-child",
                reduceWhiteSpace: false
            })

            const tl = gsap.timeline()

            childSplit.words.forEach(i => {

                i.parentNode.style.height = i.clientHeight + 'px'
                i.parentNode.style.overflow = 'hidden'
                // i.parentNode.style.background = 'red'
            })

            gsap.from(childSplit.words, {
                duration: 1,
                // delay: .02,
                yPercent: 150,
                alpha: 1,
                // ease: 'power4.out',
                // stagger: .06,
                scrollTrigger: {
                    trigger: item,
                    toggleActions: "restart none none reset",
                    // start: '-250',
                    // start: "top top",
                    end: `+ ${item.clientHeight}`,
                    // markers: true
                    once: true,
                }
            })
        });                          // do stuff

        // })

    }, [getAboutData])


    console.log('overview', overview)

    return (
        <>
            <InnerBanner title={banner?.section_data?.subtitle} img={banner?.images?.list?.[0]?.full_path}/>
            <OverviewUpdated
                title={overview?.section_data?.short_desc}
                subtitle={overview?.section_data?.subtitle}
                description={overview?.section_data?.description}
                subColor={'#FFFFFF'}
                link={'/'}
            />
            <Directors data={directors}/>
            <Accordion data={accordion}/>
            <MissionVision data={mission}/>
        </>
    );
};



export default MyComponent;
