"use client";
import styled from "styled-components";
import {Container} from "react-bootstrap";
import Img from "@/components/Img";
import Title from "@/components/Title";
import {hover, text} from "@/styles/globalStyleVars";
import {Swiper, SwiperSlide} from "swiper/react";
import 'swiper/swiper-bundle.css';
import {Autoplay, EffectCreative, Navigation, Pagination} from "swiper";
import PopupV1 from "@/components/PopupV1";
import {useState} from "react";
import reactHtmlParser from "react-html-parser";

const MyComponent = ({data}) => {
    const [show, setShow] = useState(false);
    const [popupId, setPopupId] = useState();

    const handleClose = () => setShow(false);
    const handleShow = (e) => {
        setShow(true);
        setPopupId(e);
    };

    return (
        <StyledComponent className={'directors pt-120 pb-120'}>
            <Container>
                <div className={'directors__top'}>
                    <Title text={'Board of Directors'}/>
                    <div className={'navigation'}>
                        <ul>
                            <li id={'next-director'} className={`hover ${data?.posts?.list?.length <= 3 ? 'disabled' : ''}`}>
                                <svg xmlns="http://www.w3.org/2000/svg" width="8.414" height="14.828" viewBox="0 0 8.414 14.828">
                                    <path id="Path_9659" data-name="Path 9659" d="M118.869,2934.275l-6,6,6,6" transform="translate(-111.87 -2932.861)" fill="none" stroke="#137ec3" stroke-linecap="round" stroke-linejoin="round" stroke-width="2"/>
                                    <path id="Path_9660" data-name="Path 9660" d="M118.869,2934.275l-6,6,6,6" transform="translate(-111.87 -2932.861)" fill="none" stroke="#ffffff" stroke-linecap="round" stroke-linejoin="round" stroke-width="2"/>
                                </svg>
                            </li>
                            <li id={'prev-director'} className={`hover ${data?.posts?.list?.length <= 3 ? 'disabled' : ''}`}>
                                <svg xmlns="http://www.w3.org/2000/svg" width="8.414" height="14.828" viewBox="0 0 8.414 14.828">
                                    <path id="Path_9657" data-name="Path 9657" d="M118.869,2934.275l-6,6,6,6" transform="translate(120.283 2947.689) rotate(180)" fill="none" stroke="#137ec3" stroke-linecap="round" stroke-linejoin="round" stroke-width="2"/>
                                    <path id="Path_9658" data-name="Path 9658" d="M118.869,2934.275l-6,6,6,6" transform="translate(120.283 2947.689) rotate(180)" fill="none" stroke="#ffffff" stroke-linecap="round" stroke-linejoin="round" stroke-width="2"/>
                                </svg>
                            </li>
                        </ul>
                    </div>
                </div>
                <div>
                    {
                        data?.posts?.list &&
                        <Swiper
                            modules={[Autoplay, Pagination, Navigation, EffectCreative]}
                            loop={true}
                            allowTouchMove={true}
                            autoplay={false}
                            slidesPerView={1}
                            spaceBetween={30}
                            pagination={false}
                            navigation={{
                                prevEl: '#prev-director',
                                nextEl: '#next-director',
                            }}
                            breakpoints={{
                                900: {
                                    slidesPerView: 3,
                                },
                                550: {
                                    slidesPerView: 1,
                                }

                            }}

                            speed={900}
                        >
                            {
                                data?.posts?.list?.map((e, i) => (
                                    <SwiperSlide key={i}>
                                        <div className={'directors__single'} onClick={() => handleShow(e)}>
                                            <div className={'directors__single__data reveal-img'}>
                                                <div className={'directors__single__data__img'}>
                                                    <Img src={'/images/dynamic/about/chairman.jpg'}/>
                                                </div>
                                                <div className={'directors__single__data__content'}>
                                                    <h5>{e?.data?.title}</h5>
                                                    <span>{e?.data?.subtitle}</span>
                                                    <p>
                                                        {reactHtmlParser(e?.data?.short_desc)}
                                                    </p>
                                                    <div className={'button'}>
                                                        <p>Read more</p>
                                                        <svg xmlns="http://www.w3.org/2000/svg" width="20.5" height="5" viewBox="0 0 20.5 5">
                                                            <g id="Group_21340" data-name="Group 21340" transform="translate(-19 -670)">
                                                                <path id="Polygon_2" data-name="Polygon 2" d="M2.5,0,5,4H0Z" transform="translate(39.5 670) rotate(90)" fill="#5c5550"/>
                                                                <line id="Line_3986" data-name="Line 3986" x1="16" transform="translate(19.5 672.5)" fill="none" stroke="#5c5550" stroke-linecap="round" stroke-width="1"/>
                                                            </g>
                                                        </svg>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </SwiperSlide>
                                ))
                            }
                        </Swiper>
                    }
                </div>
            </Container>
            <PopupV1 show={show} data={popupId} handleClose={handleClose}/>
        </StyledComponent>
    );
};

const StyledComponent = styled.section`
    background-color: #F9F9F9;
  .directors{
    &__top{
      margin-bottom: 40px;
      display: flex;
      justify-content: space-between;

      .navigation{
        ul{
          display: flex;
          gap: 15px;

          li{
            height: 40px;
            width: 40px;
            border: 1px solid #137EC3;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
              &.disabled {
                  opacity: 0.5;
                  cursor: not-allowed;
                  pointer-events: none;
              }
            svg{
              position: relative;
              z-index: 999999;
              #Path_9658, #Path_9660{
                display: none;
                transition: all 0.2s ease-in-out;
              }
            }

            &:hover{
              svg{
                #Path_9658, #Path_9660{
                  display: block !important;
                }
                #Path_9657, #Path_9659{
                  display: none;
                }
              }
            }

              @media(max-width: 767px){
                  &.disabled {
                      opacity: 1;
                      cursor: unset;
                      pointer-events: unset;
                  }
              }
          }
        }
      }
    }

    &__single{
      &__data{
        &__img{
          position: relative;
          padding-top: calc(370 / 370 * 100%);
          overflow: hidden;
          border-radius: 0 50px;
          margin-bottom: 20px;

          .global-image{
            img{
              transform: scale(1);
              transition: transform .7s cubic-bezier(0.4, 0, 0, 1);
            }
          }

          &:hover{
            cursor: pointer;
            .global-image{
              img{
                transform: scale(1.04);
                transition: transform .7s cubic-bezier(0.4, 0, 0, 1);
              }
            }
          }
        }
        &__content{
          h5{
            margin-bottom: 10px;
          }
          span{
            font-size: 16px;
            line-height: 20px;
            font-weight: 500;
            color: ${hover};
          }
          p{
            margin-top: 20px;
            font-size: 16px;
            line-height: 20px;
            font-weight: 400;
            color: ${text};
            opacity: 70%;
          }

          .button{
            margin-top: 20px;
            display: flex;
            align-items: center;
            gap: 15px;
            transition: all 0.3s ease-in-out;
            cursor: pointer;
            p{
              margin-top: 0;
              opacity: unset;
            }

            &:hover{
              gap: 20px;
              p{
                color: ${hover};
              }
            }
          }
        }
      }
    }
  }
`;

export default MyComponent;
