'use client';
import InnerBanner from "@/components/InnerBanner";
import Consumer from "@/components/business/Consumer";
import Paper from "@/components/business/Paper";
import Service from "@/components/business/Service";
import {useEffect, useState} from "react";
import {getProductApi} from "@/api/product";
import { ScrollTrigger } from "gsap/ScrollTrigger";
import { CSSPlugin, gsap } from "gsap";
import {SplitText} from "gsap/SplitText";

const MyComponent = () => {
    gsap.registerPlugin(ScrollTrigger, CSSPlugin);
    const [getPageData, setPageData] = useState(null);

    useEffect(() => {
        const fetchAboutData = async () => {
            const data = await getProductApi();
            setPageData(data);
        };

        fetchAboutData();
    }, []);

    //Refactor
    const banner = getPageData?.data?.sections?.find(f=>f?.section_data?.template === 'inner_banner');
    const products = getPageData?.all_products?.list;

    //content animation
    useEffect(() => {
        let allAnim = document.querySelectorAll('.fade-up');
        allAnim.forEach((el, index) => {
            gsap.fromTo(el, {
                autoAlpha: 0,
                y: 100,
                ease: "none",
            }, {
                y: 0,
                autoAlpha: 1,
                ease: "power2",
                duration: 1.5,
                scrollTrigger: {
                    id: `${index + 1}`,
                    trigger: el,
                    start: 'top center+=150',
                    toggleActions: 'play none none reverse',
                }
            })
        })
        return (() => {
            allAnim = ''
        })
    }, [ getPageData])
    //text animation
    useEffect(() => {
        // ScrollTrigger.refresh();
        // document.fonts.ready.then(() => {

        gsap.utils.toArray('.split-up').forEach((item, i) => {
            const parentSplit = new SplitText(item, {
                wordsClass: "split-parent",
                type: "words",
                reduceWhiteSpace: false
            })
            const childSplit = new SplitText(item, {
                type: "words",
                wordsClass: "split-child",
                reduceWhiteSpace: false
            })

            const tl = gsap.timeline()

            childSplit.words.forEach(i => {

                i.parentNode.style.height = i.clientHeight + 'px'
                i.parentNode.style.overflow = 'hidden'
                // i.parentNode.style.background = 'red'
            })

            gsap.from(childSplit.words, {
                duration: 1,
                // delay: .02,
                yPercent: 150,
                alpha: 1,
                // ease: 'power4.out',
                // stagger: .06,
                scrollTrigger: {
                    trigger: item,
                    toggleActions: "restart none none reset",
                    // start: '-250',
                    // start: "top top",
                    end: `+ ${item.clientHeight}`,
                    // markers: true
                    once: true,
                }
            })
        });                          // do stuff

        // })

    }, [getPageData])

    return (
        <>
            <InnerBanner title={banner?.section_data?.subtitle} img={banner?.images?.list?.[0]?.full_path} color={'#ffffff'}/>
            <Consumer data={products}/>
            <Paper data={products}/>
            <Service data={products}/>
        </>
    );
};


export default MyComponent;
