'use client';

import {getProductDetailApi} from "@/api/product";
import { ScrollTrigger } from "gsap/ScrollTrigger";
import { CSSPlugin, gsap } from "gsap";
import {SplitText} from "gsap/SplitText";
import {usePathname} from "next/navigation";
import {useEffect, useState} from "react";
import BannerSlider from "@/components/business/BannerSlider";
import OverviewUpdated from "@/components/OverviewUpdated";
import Quality from "@/components/business/Quality";
import Variation from "@/components/business/Variation";
import RelatedProduct from "@/components/business/RelatedProduct";


const MyComponent = () => {
    const location = usePathname();
    const slug = location.split('/')[2];
    console.log('slug', slug)
    gsap.registerPlugin(ScrollTrigger, CSSPlugin);
    const [productData, setproductData] = useState(null);

    useEffect(() => {
        const fetchAboutData = async () => {
            if (slug) {
                const data = await getProductDetailApi(slug);
                setproductData(data);
            }
        };
        fetchAboutData();
    }, []);

    //Refactor
    const banner = productData?.data?.posts?.list?.find(f=>f?.data?.template === 'inner_banner');
    const overview = productData?.data?.posts?.list?.find(f=>f?.data?.template === 'overview');
    const variation = productData?.data?.posts?.list?.find(f=>f?.data?.template === 'variation');
    const quality = productData?.data?.posts?.list?.filter(f=>f?.data?.template === 'quality');
    const relatedproduct = productData?.related_product?.list?.filter(f=>f?.product_data?.slug !== slug);


    //content animation
    useEffect(() => {
        let allAnim = document.querySelectorAll('.fade-up');
        allAnim.forEach((el, index) => {
            gsap.fromTo(el, {
                autoAlpha: 0,
                y: 100,
                ease: "none",
            }, {
                y: 0,
                autoAlpha: 1,
                ease: "power2",
                duration: 1.5,
                scrollTrigger: {
                    id: `${index + 1}`,
                    trigger: el,
                    start: 'top center+=150',
                    toggleActions: 'play none none reverse',
                }
            })
        })
        return (() => {
            allAnim = ''
        })
    }, [ productData])
    //text animation
    useEffect(() => {
        // ScrollTrigger.refresh();
        // document.fonts.ready.then(() => {

        gsap.utils.toArray('.split-up').forEach((item, i) => {
            const parentSplit = new SplitText(item, {
                wordsClass: "split-parent",
                type: "words",
                reduceWhiteSpace: false
            })
            const childSplit = new SplitText(item, {
                type: "words",
                wordsClass: "split-child",
                reduceWhiteSpace: false
            })

            const tl = gsap.timeline()

            childSplit.words.forEach(i => {

                i.parentNode.style.height = i.clientHeight + 'px'
                i.parentNode.style.overflow = 'hidden'
                // i.parentNode.style.background = 'red'
            })

            gsap.from(childSplit.words, {
                duration: 1,
                // delay: .02,
                yPercent: 150,
                alpha: 1,
                // ease: 'power4.out',
                // stagger: .06,
                scrollTrigger: {
                    trigger: item,
                    toggleActions: "restart none none reset",
                    // start: '-250',
                    // start: "top top",
                    end: `+ ${item.clientHeight}`,
                    // markers: true
                    once: true,
                }
            })
        });                          // do stuff

        // })

    }, [productData])

    return (
        <>
            <BannerSlider data={banner}/>
            <div id={'overview'}>
                <OverviewUpdated title={overview?.data?.short_desc} subtitle={overview?.data?.subtitle} description={overview?.data?.description} subColor={'#ffffff'} />
                {/*<Overview title={overview?.data?.short_desc} subtitle={overview?.data?.subtitle} description={overview?.data?.description} variation={variation}  />*/}
            </div>
            <Quality data={quality}/>
            <Variation variation={variation}/>
            <RelatedProduct data={relatedproduct}/>
        </>
    );
};


export default MyComponent;
