"use client";
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import SubTitle from "@/components/SubTitle";
import Button from "@/components/Button";
import sku1 from "@/public/images/dynamic/business/1kg.png"
import sku2 from "@/public/images/dynamic/business/5kg.png"
import Image from "next/image";
import {hover} from "@/styles/globalStyleVars";
import {Swiper, SwiperSlide} from "swiper/react";
import {Autoplay, EffectCreative, Navigation, Pagination} from "swiper";
import reactHtmlParser from "react-html-parser";

const Overview = ({ subtitle, title, description, link, variation}) => {
    console.log('variation', variation)
    return (
        <StyledComponent className={'overview pt-120 pb-120'} id={'overview'}>
            <Container>
                <Row>
                    <Col md={6} className={'overview__left'}>
                        <SubTitle text={ subtitle ? subtitle : 'Muskan Salt'} color={'#137EC3'}/>
                        <h4 className={'split-up'}>
                            {title ? reactHtmlParser(title) : ''}
                        </h4>
                    </Col>
                    <Col md={{offset:1, span:5}}>
                        <p className={'split-up'}>
                            {description ? reactHtmlParser(description) : ''}
                        </p>
                        {
                            link ?
                                <Button text={'Read More'} margin={'40px 0 0'} src={link}/>
                                :
                                ''
                        }
                    </Col>
                </Row>
                <div className={'sku'}>
                    {
                        variation &&
                        <Swiper
                            modules={[Autoplay, Pagination, Navigation, EffectCreative]}
                            loop={true}
                            allowTouchMove={true}
                            autoplay={false}
                            slidesPerView={1}
                            spaceBetween={30}
                            pagination={false}
                            navigation={{
                                prevEl: '#prev-business',
                                nextEl: '#next-business',
                            }}
                            breakpoints={{
                                900: {
                                    slidesPerView: 3,
                                },
                                550: {
                                    slidesPerView: 1,
                                }

                            }}

                            speed={900}
                        >
                            {
                                variation?.images?.length > 0 &&
                                variation?.images?.map((e,i)=>{
                                    return(
                                        <SwiperSlide key={i}>
                                            <div className={'sku__single'}>
                                                <div className={'sku__single__data'}>
                                                    <div className={'img-wrapper'}>
                                                        <img src={e?.full_path}/>
                                                    </div>
                                                    <h5>{e?.short_title}</h5>
                                                </div>
                                            </div>
                                        </SwiperSlide>
                                    );
                                })
                            }
                        </Swiper>
                    }

                </div>
            </Container>
        </StyledComponent>
    );
};

const StyledComponent = styled.section`
  
  .sku{
    margin-top: 100px;
    &__single{
      &__data{
        text-align: center;
        .img-wrapper{
          height: 250px;
          display: flex;
          align-items: center;
          justify-content: center;
          background-color: #F9F9F9;
          border-radius: 0 50px;
          margin-bottom: 20px;
          cursor: pointer;
          img{
            transform: scale(1);
            transition: transform 0.3s ease-in-out;
          }
          
          &:hover{
            img{
              transform: scale(1.06);
              transition: transform 0.3s ease-in-out;
            }
          }
        }
        h5{
          color: ${hover};
        }
      }
    }
  }

  @media(max-width: 767px){
    .overview__left{
      margin-bottom: 40px;
    }
  }
`;

export default Overview;
