'use client';
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import Link from 'next/link'
import {useEffect, useState} from "react";
import {getCareerApi} from "@/api/career";
import InnerBanner from "@/components/InnerBanner";
import Philosophy from "@/components/career/Philosophy";
import TalentManagement from "@/components/career/TalentManagement";
import EmployeeEngagement from "@/components/career/EmployeeEngagement";
import EventActivation from "@/components/career/EventActivation";
import EmployeeBenefits from "@/components/career/EmployeeBenefits";
import SkillSafety from "@/components/career/SkillSafety";
import { ScrollTrigger } from "gsap/ScrollTrigger";
import { CSSPlugin, gsap } from "gsap";
import {SplitText} from "gsap/SplitText";

const MyComponent = () => {
    gsap.registerPlugin(ScrollTrigger, CSSPlugin);
    const [getCareerData, setCareerData] = useState(null);

    useEffect(() => {
        const fetchAboutData = async () => {
            const data = await getCareerApi();
            setCareerData(data);
        };

        fetchAboutData();
    }, []);

    //Refactor
    const banner = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'inner_banner');
    const philosophy = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'employee_philosophy');
    const talent = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'team_management');
    const engagement = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'employee_engagement');
    const event = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'event_activation');
    const benefits = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'employee_benefits');
    const skillsafety = getCareerData?.data?.sections?.find(f=>f?.section_data?.template === 'skill_development');


    //image reveal
    useEffect(() => {

        let reveal = gsap.utils.toArray(".reveal-img");
        reveal.forEach((cont) => {
            let img = cont.querySelector("img");
            let tl = gsap.timeline({
                scrollTrigger: {
                    trigger: cont,
                    toggleActions: "restart none none reset",
                    once: true,
                },
            });

            // clip-path reveal
            tl.from(
                img,
                1.5,
                {
                    clipPath: "inset(0% 0% 100% 0%)", // Start from bottom
                    ease: "power2.inOut",
                },
                {
                    clipPath: "inset(0% 0% 0% 0%)", // Move to top
                    ease: "power2.inOut",
                }
            );
        });


    }, [ getCareerData]);
    //content animation
    useEffect(() => {
        let allAnim = document.querySelectorAll('.fade-up');
        allAnim.forEach((el, index) => {
            gsap.fromTo(el, {
                autoAlpha: 0,
                y: 100,
                ease: "none",
            }, {
                y: 0,
                autoAlpha: 1,
                ease: "power2",
                duration: 1.5,
                scrollTrigger: {
                    id: `${index + 1}`,
                    trigger: el,
                    start: 'top center+=150',
                    toggleActions: 'play none none reverse',
                }
            })
        })
        return (() => {
            allAnim = ''
        })
    }, [ getCareerData]);
    //text animation
    useEffect(() => {
        // ScrollTrigger.refresh();
        // document.fonts.ready.then(() => {

        gsap.utils.toArray('.split-up').forEach((item, i) => {
            const parentSplit = new SplitText(item, {
                wordsClass: "split-parent",
                type: "words",
                reduceWhiteSpace: false
            })
            const childSplit = new SplitText(item, {
                type: "words",
                wordsClass: "split-child",
                reduceWhiteSpace: false
            })

            const tl = gsap.timeline()

            childSplit.words.forEach(i => {

                i.parentNode.style.height = i.clientHeight + 'px'
                i.parentNode.style.overflow = 'hidden'
                // i.parentNode.style.background = 'red'
            })

            gsap.from(childSplit.words, {
                duration: 1,
                // delay: .02,
                yPercent: 150,
                alpha: 1,
                // ease: 'power4.out',
                // stagger: .06,
                scrollTrigger: {
                    trigger: item,
                    toggleActions: "restart none none reset",
                    // start: '-250',
                    // start: "top top",
                    end: `+ ${item.clientHeight}`,
                    // markers: true
                    once: true,
                }
            })
        });                          // do stuff

        // })

    }, [getCareerData]);

    return (
        <>
            <InnerBanner title={banner?.section_data?.subtitle} img={banner?.images?.list?.[0]?.full_path} color={'#ffffff'}/>
            <Philosophy data={philosophy}/>
            <TalentManagement data={talent}/>
            <EmployeeEngagement data={engagement}/>
            <EventActivation data={event}/>
            <EmployeeBenefits data={benefits}/>
            <SkillSafety data ={skillsafety}/>
        </>
    );
};



export default MyComponent;
