"use client";
import { useEffect, useRef, useState } from 'react';
import styled from 'styled-components';
import Modal from "react-bootstrap/Modal";
import { Col, Container, Form, Row } from "react-bootstrap";
import SimpleBar from 'simplebar-react';
import 'simplebar-react/dist/simplebar.min.css';
import reactHtmlParser from "react-html-parser";
import Subtitle from "@/components/SubTitle";
import idcard from "@/public/images/dynamic/career/career.jpg";
import Image from "next/image";
import Button from "@/components/Button";
import { useForm } from "react-hook-form";
import { toast } from "react-toastify";
import axios from "axios";
import { Loading } from "@/components/Loading";

const PopupV1 = ({
                     show,
                     handleClose,
                     no_img,
                     item,
                     title,
                     description,
                     data,
                     subtitle,
                     img,
                 }) => {

    let [open, setOpen] = useState(false);
    let [videoId, setVideo] = useState('');
    const modalRef = useRef(null);

    const [isSubmitting, setIsSubmitting] = useState(false);
    const popupData = data;
    const [winWidth, setWinWidth] = useState(true);
    useEffect(() => {
        if (window.innerWidth > 767) {
            setWinWidth(true);
        } else {
            setWinWidth(false);
        }
        window.addEventListener("resize", () => {
            if (window.innerWidth > 767) {
                setWinWidth(true);
            } else {
                setWinWidth(false);
            }
        });
    }, []);


    const { register, handleSubmit, formState, reset } = useForm({ mode: 'all' });
    const { errors } = formState;

    const success = (msg) => toast.success(msg, {
        position: "top-right", autoClose: 4000, closeOnClick: true, progress: undefined,
    });

    const error = (msg) => toast.error(msg, {
        position: "top-right", autoClose: 4000, closeOnClick: true, progress: undefined,
    });

    const onSubmit = async (data) => {
        if(!cv){
            setCvError('Please upload your CV')
            return;
        }
        setIsSubmitting(true);
        try {
            const formData = new FormData();
            formData.append('name', data?.name);
            formData.append('email', data?.email);
            formData.append('phone', data?.phone);
            formData.append('cover', data?.cover);
            formData.append('position', data?.position);
            formData.append('file', cv);
            formData.append('form_id', 'career-form');

            const response = await axios.post('https://bestinbd.com/projects/web/2309SAG/api/post-req-data/form-submit', formData);

            if (response.status === 200) {
                success('Form submitted successfully');
                reset(); // Reset form fields
                setUploadText('Upload CV*');
                setCv(null);
            } else {
                error('Failed to submit form. Please try again later.');
            }
        } catch (error) {
            error('Failed to submit form. Please try again later.');
        } finally {
            setIsSubmitting(false); // Hide spinner
        }
    };

    const [uploadText, setUploadText] = useState('Upload CV*');
    const [cv, setCv] = useState(null);
    const [cvError, setCvError] = useState(null);
    const cvRef = useRef();

    const handleUploadClick = () => {
        cvRef.current.click();
    };

    const handleUpload = (event) => {
        const selectedFile = event.target.files[0];

        if (selectedFile) {
            const fileName = selectedFile.name;
            const fileSize = selectedFile.size;
            const fileType = selectedFile.type;

            if (fileType !== 'application/pdf') {
                setCvError('Please upload a PDF file.');
                setUploadText('Upload CV*');
                setCv(null);
            } else if (fileSize > 2 * 1024 * 1024) { // 2MB limit
                setCvError('File size should be less than 2MB.');
                setUploadText('Upload CV*');
                setCv(null);
            } else {
                setCv(selectedFile);
                setUploadText(fileName);
                setCvError(null);
                document.querySelector('.gph_upload').classList.add('hide');
            }
        }
    };

    return (
        <StyledModal>
            <Modal
                show={show}
                item={item}
                onHide={handleClose}
                backdrop="static"
                keyboard={false}
                className="gph_modal popup-version-one career"
            >
                {isSubmitting === true && <Loading />}
                <SimpleBar className="main_scroll" style={{ height: '100vh' }}>
                    <Modal.Body>
                        <Container className={'bar'}>
                            <div className={'for-close d-flex justify-content-between'}>
                                <Subtitle text={'Apply on SA Group'} />
                                <div onClick={handleClose} className="modal-close ">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="17.414" height="17.414" viewBox="0 0 17.414 17.414">
                                        <g id="Group_21430" data-name="Group 21430" transform="translate(-1252.722 -58.222)">
                                            <line id="Line_3989" data-name="Line 3989" y2="22.627" transform="translate(1269.429 58.929) rotate(45)" fill="none" stroke="#000" stroke-linecap="round" stroke-width="1" />
                                            <line id="Line_3990" data-name="Line 3990" y2="22.627" transform="translate(1269.429 74.929) rotate(135)" fill="none" stroke="#000" stroke-linecap="round" stroke-width="1" />
                                        </g>
                                    </svg>
                                </div>
                            </div>
                        </Container>
                        <Container>
                            <Row>
                                <div className="modal-data d-flex">
                                    <Col sm={8} className='modal-data__content'>
                                        <div className="scroll-div">
                                            <SimpleBar autoHide={true} style={{ maxHeight: 'calc(100vh - 100px)' }}>
                                                <Form onSubmit={handleSubmit(onSubmit)}>
                                                    <Form.Group className={'from-group d-flex'}>
                                                        <div className="input-container">
                                                            <Form.Control
                                                                className={errors?.name ? 'has-error form-control-lg' : 'form-control-lg'}
                                                                {...register("name", {
                                                                    required: 'Please enter your Name',
                                                                    pattern: {
                                                                        value: /^[A-Za-z ]+$/,
                                                                        message: 'Name must contain only letters',
                                                                    },
                                                                })}
                                                                type="text" placeholder="Enter your full name*" />
                                                            {errors.name && <span className="error-message">{errors.name.message}</span>}
                                                        </div>
                                                        <div className="input-container">
                                                            <Form.Control
                                                                className={errors?.position ? 'has-error form-control-lg' : 'form-control-lg'}
                                                                {...register("position", {
                                                                    required: 'Please enter your Position',
                                                                    pattern: {
                                                                        value: /^[A-Za-z ]+$/,
                                                                        message: 'Position must contain only letters',
                                                                    },
                                                                })}
                                                                type="text" placeholder="Position*" />
                                                            {errors.position && <span className="error-message">{errors.position.message}</span>}
                                                        </div>
                                                    </Form.Group>
                                                    <Form.Group className={'from-group d-flex'}>
                                                        <div className="input-container">
                                                            <Form.Control
                                                                className={errors?.phone ? 'has-error form-control-lg' : 'form-control-lg'}
                                                                {...register("phone", {
                                                                    required: 'Please enter your phone number',
                                                                    pattern: {
                                                                        value: /^01[0-9]{9}$/,
                                                                        message: 'Please enter a valid 11 digit phone number',
                                                                    },
                                                                })}
                                                                type="number" placeholder="Enter your phone number*" />
                                                            {errors.phone && <span className="error-message">{errors.phone.message}</span>}
                                                        </div>
                                                        <div className="input-container">
                                                            <Form.Control
                                                                className={errors?.email ? 'has-error form-control-lg' : 'form-control-lg'}
                                                                {...register("email", {
                                                                    required: 'Please enter your email',
                                                                    pattern: {
                                                                        value: /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,}$/i,
                                                                        message: 'Please enter a valid email address',
                                                                    },
                                                                })}
                                                                type="email" placeholder="Enter your email address*" />
                                                            {errors.email && <span className="error-message">{errors.email.message}</span>}
                                                        </div>
                                                    </Form.Group>
                                                    <div className="input-container">
                                                        <textarea
                                                            className={errors?.cover ? 'form-control-lg textarea form-control has-error' : 'textarea form-control form-control-lg'}
                                                            {...register('cover', {
                                                                required: 'Please enter your cover letter',
                                                            })}
                                                            placeholder={'Enter your cover letter*'} />
                                                        {errors.cover && <span className="error-message">{errors.cover.message}</span>}
                                                    </div>
                                                    <div className={'buttons d-flex'}>
                                                        <Form.Group className={'upload'}>
                                                            <Form.Control
                                                                ref={cvRef}
                                                                onChange={handleUpload}
                                                                className={'gph_upload'}
                                                                text={uploadText}
                                                                type="file"
                                                                accept=".pdf"
                                                            />
                                                            {errors.cv && <span className="error-message">{errors.cv.message}</span>}
                                                            {cvError && <span className="error-message">{cvError}</span>}
                                                        </Form.Group>
                                                        <div className="button" onClick={handleSubmit(onSubmit)}>
                                                            <Button text={'Apply'} />
                                                        </div>
                                                    </div>
                                                </Form>
                                            </SimpleBar>
                                        </div>
                                    </Col>
                                    <Col sm={4} className="modal-data__img">
                                        <div className={'image-wrapp'}>
                                            <Image src={idcard} />
                                        </div>
                                    </Col>
                                </div>
                            </Row>
                        </Container>
                    </Modal.Body>
                </SimpleBar>
            </Modal>
        </StyledModal>
    )
};

const StyledModal = styled.div`
    position: relative;
    .modal-dialog {
        margin: 0;
    }
    .error-message {
        color: red;
        margin-top: 5px;
        margin-bottom: 10px;
    }
    .input-container {
        flex: 1;
        display: flex;
        flex-direction: column;
        margin-right: 10px;
    }
    .upload-label {
        display: block;
        margin-bottom: 5px;
        cursor: pointer;
        color: #000;
        font-size: 1rem;
    }
`;

export default PopupV1;
