"use client";
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import Button from "@/components/Button";
import Img from "@/components/Img";
import reactHtmlParser from "react-html-parser";
import CsrPopup from "@/components/csr/CsrPopup";
import {useState} from "react";
import { gsap } from "gsap";
import { ScrollTrigger } from "gsap/ScrollTrigger";
gsap.registerPlugin(ScrollTrigger);

const MyComponent = ({data}) => {
    const [show, setShow] = useState(false);
    const [popupId, setPopupId] = useState();

    const handleClose = () => setShow(false);
    const handleShow = (e) => {
        setShow(true);
        setPopupId(e);
    };


    //loadmore functionality
    const [itemsToShow, setItemsToShow] = useState(4);
    const [isCompleted, setIsCompleted] = useState(false)

    const handleLoadMore = () => {
        setItemsToShow((prevItemsToShow) => {
            const newItemsToShow = prevItemsToShow + 4;
            if (newItemsToShow >= data?.posts?.list?.length) {
                setIsCompleted(true);
            }
            return newItemsToShow;
        });
        gsap.delayedCall(0.1, ScrollTrigger.refresh);
    };
    return (
        <StyledComponent className={'pt-120 pb-120'}>
            <Container className={'csr'}>
                <Row>
                    {
                        data?.posts?.list && data?.posts?.list?.length > 0 &&
                        data?.posts?.list?.slice(0, itemsToShow)?.map((e, i)=>{
                            return (
                                <Col md={6} className={'csr__single'} key={i}>
                                    <div className={'csr__single__img reveal-img'}>
                                        <Img src={e?.images?.[0]?.full_path}/>
                                    </div>
                                    <p>
                                        {reactHtmlParser(e?.data?.description)}
                                    </p>
                                    <div className="btn" onClick={() => handleShow(e)}>
                                        <Button
                                            text={'Read More'}
                                            color={'#000000'}
                                            svgColor={'#000000'}
                                        />
                                    </div>
                                </Col>
                            );
                        })
                    }

                    {
                        !isCompleted && data?.posts?.list?.length > itemsToShow &&
                        <Col md={12} className={'loadmore'} onClick={handleLoadMore}>
                            <Button text={'Load More'} margin={'60px 0 0'}/>
                        </Col>
                    }

                </Row>
            </Container>
            <CsrPopup show={show} data={popupId} handleClose={handleClose}/>
        </StyledComponent>
    );
};

const StyledComponent = styled.section`
    background-color: #F9F9F9;
  
  .csr{
    &__single{
      margin-bottom: 40px;
      &:last-child{
        margin-bottom: 0;
      }
      &:nth-last-child(2){
        margin-bottom: 0;
      }
      &__img{
        position: relative;
        overflow: hidden;
        padding-top: calc(400 / 570 * 100%);
        border-radius: 0 50px;
        cursor: pointer;
        margin-bottom: 20px;
        .global-image{
          img{
            transform: scale(1);
            transition: transform .7s cubic-bezier(0.4, 0, 0, 1);
          }
        }
        &:hover{
          .global-image{
            img{
              transform: scale(1.04);
              transition: transform .7s cubic-bezier(0.4, 0, 0, 1);
            }
          }
        }
      }
      p{
        color: rgba(0 0 0 / .75);
          display: -webkit-box;
          -webkit-box-orient: vertical;
          overflow: hidden;
          text-overflow: ellipsis;
          -webkit-line-clamp: 3; /* Limit to 5 lines */
          line-clamp: 3;
      }
        
        .btn{
            padding: 30px 0 0;
            
            .dc-btn{
                padding: 0;
                height: unset;

                a{
                    padding: 0;
                    background-color: unset;
                }
            }
        }
        
    }
      
      .loadmore{
          .dc-btn{
              display: flex;
              justify-content: center;
          }
      }
  }
`;

export default MyComponent;
