'use client';
import {getNewsDetailApi, getPressApi} from "@/api/news";
import {useEffect, useState} from "react";
import { ScrollTrigger } from "gsap/ScrollTrigger";
import { CSSPlugin, gsap } from "gsap";
import {SplitText} from "gsap/SplitText";
import NewsDetails from "@/components/news/NewsDetails";
import PressSlider from "@/components/news/PressSlider";
import {usePathname, useRouter} from "next/navigation";

const MyComponent = () => {
    gsap.registerPlugin(ScrollTrigger, CSSPlugin);
    const [getNewsData, setNewsData] = useState(null);
    const [press, setpress] = useState(null);
    const location = usePathname();
    const slug = location.split('/')[2];


    useEffect(() => {
        const fetchAboutData = async () => {
            if (slug) {
                const data = await getNewsDetailApi(slug);
                setNewsData(data);
            }
        };

        const fetchPressData = async () => {
            const presss = await getPressApi();
            setpress(presss);
        }

        fetchAboutData();
        fetchPressData();
    }, []);



    //image reveal
    useEffect(() => {

        let reveal = gsap.utils.toArray(".reveal-img");
        reveal.forEach((cont) => {
            let img = cont.querySelector("img");
            let tl = gsap.timeline({
                scrollTrigger: {
                    trigger: cont,
                    toggleActions: "restart none none reset",
                    once: true,
                },
            });

            // clip-path reveal
            tl.from(
                img,
                1.5,
                {
                    clipPath: "inset(0% 0% 100% 0%)", // Start from bottom
                    ease: "power2.inOut",
                },
                {
                    clipPath: "inset(0% 0% 0% 0%)", // Move to top
                    ease: "power2.inOut",
                }
            );
        });


    }, [ getNewsData]);
    //content animation
    useEffect(() => {
        let allAnim = document.querySelectorAll('.fade-up');
        allAnim.forEach((el, index) => {
            gsap.fromTo(el, {
                autoAlpha: 0,
                y: 100,
                ease: "none",
            }, {
                y: 0,
                autoAlpha: 1,
                ease: "power2",
                duration: 1.5,
                scrollTrigger: {
                    id: `${index + 1}`,
                    trigger: el,
                    start: 'top center+=150',
                    toggleActions: 'play none none reverse',
                }
            })
        })
        return (() => {
            allAnim = ''
        })
    }, [ getNewsData, press]);
    //text animation
    useEffect(() => {
        // ScrollTrigger.refresh();
        // document.fonts.ready.then(() => {

        gsap.utils.toArray('.split-up').forEach((item, i) => {
            const parentSplit = new SplitText(item, {
                wordsClass: "split-parent",
                type: "words",
                reduceWhiteSpace: false
            })
            const childSplit = new SplitText(item, {
                type: "words",
                wordsClass: "split-child",
                reduceWhiteSpace: false
            })

            const tl = gsap.timeline()

            childSplit.words.forEach(i => {

                i.parentNode.style.height = i.clientHeight + 'px'
                i.parentNode.style.overflow = 'hidden'
                // i.parentNode.style.background = 'red'
            })

            gsap.from(childSplit.words, {
                duration: 1,
                // delay: .02,
                yPercent: 150,
                alpha: 1,
                // ease: 'power4.out',
                // stagger: .06,
                scrollTrigger: {
                    trigger: item,
                    toggleActions: "restart none none reset",
                    // start: '-250',
                    // start: "top top",
                    end: `+ ${item.clientHeight}`,
                    // markers: true
                    once: true,
                }
            })
        });                          // do stuff

        // })

    }, [getNewsData, press])

    return (
        <>
            <NewsDetails data={getNewsData}/>
            <PressSlider data={press}/>
        </>
    );
};


export default MyComponent;
