"use client";
import styled from "styled-components";
import {Container, Row, Col} from "react-bootstrap";
import Button from "@/components/Button";
import {hover} from "@/styles/globalStyleVars";
import Image from "next/image";
import reactHtmlParser from "react-html-parser";

const MyComponent = ({data}) => {

    //refactor
    const top_desc = data?.data?.posts?.list?.find(f=>f?.data?.template === 'description');
    const full_image = data?.data?.posts?.list?.find(f=>f?.data?.template === 'full_image');
    const mid_desc = data?.data?.posts?.list?.find(f=>f?.data?.template === 'description_middle');
    const image_group = data?.data?.posts?.list?.find(f=>f?.data?.template === 'image_grid');
    const bottom_desc = data?.data?.posts?.list?.find(f=>f?.data?.template === 'description_bottom');
    const dateObject = new Date(data?.data?.data?.date);
    const formattedDate = `${dateObject.getDate()} ${getMonthName(dateObject.getMonth())}, ${dateObject.getFullYear()}`;

    function getMonthName(monthIndex) {
        const months = [
            "Jan", "Feb", "Mar", "Apr", "May", "Jun",
            "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
        ];
        return months[monthIndex];
    }

    return (
        <StyledComponent className={'details pt-150'}>
            <Container>
                <div className={'details__top'}>
                    <Button text={'Back'} src={'/news-events'}/>
                </div>
                {
                    data &&
                    <Row>
                        <Col md={{offset: 2, span: 8}} className={'details__content'}>
                            <p>{formattedDate}</p>
                            <h1>{data?.data?.data?.title}</h1>

                            {
                                top_desc?.data?.description &&
                                <p className={'desc'}>
                                    {reactHtmlParser(top_desc?.data?.description)}
                                </p>
                            }

                            {
                                full_image?.images && full_image?.images?.length > 0 &&
                                <div className="details-banner reveal-img">
                                    <Image src={full_image?.images?.[0]?.full_path} objectFit={'cover'} layout={'fill'}/>
                                </div>
                            }

                            {
                                mid_desc?.data?.description &&
                                <p className={'desc'}>
                                    {
                                        reactHtmlParser(mid_desc?.data?.description)
                                    }
                                </p>
                            }


                            {
                                image_group?.images?.length > 0 &&
                                <div className="row image-group">
                                    {
                                        image_group?.images?.map((e,i)=>{
                                            return(
                                                <Col md={6} className={'image-group__single'} key={i}>
                                                    <div className="wrapper reveal-img">
                                                        <Image src={e?.full_path} objectFit={'cover'} layout={'fill'}/>
                                                    </div>
                                                </Col>
                                            );
                                        })
                                    }
                                </div>
                            }

                            {
                                bottom_desc?.data?.description &&
                                <p className={'desc'}>
                                    {
                                        reactHtmlParser(mid_desc?.data?.description)
                                    }
                                </p>
                            }
                        </Col>
                    </Row>
                }
            </Container>
        </StyledComponent>
    );
};

const StyledComponent = styled.section`
  background-color: #F9F9F9;
    padding-bottom: 40px;
  .details{
    &__top{
      padding-bottom: 23px;
      border-bottom: 1px solid rgba(92, 85, 80, 0.2) !important;
    }

    &__content{
      padding-top: 60px;
      p{
        margin-bottom: 20px;
      }
      h1{
        font-size: 42px;
        line-height: 50px;
        font-weight: 400;
        letter-spacing: -1.26px;
        color: ${hover} !important;
        margin-bottom: 40px;
        @media(max-width: 767px){
          font-size: 32px;
          line-height: 40px;
          letter-spacing: -0.96px;
        }
      }

      .desc{
        opacity: 75%;
        margin-bottom: 40px;
      }

      .details-banner{
        position: relative;
        padding-top: calc(400 / 770 * 100%);
        overflow: hidden;
        border-radius: 20px;
        margin-bottom: 40px;
        img{
          position: absolute;
          top: 0;
          left: 0;
          width: 100%;
          height: 100%;
          object-fit: cover;
        }
      }

      .image-group{
        margin-bottom: 40px;
        &__single{
          margin-bottom: 20px;
          .wrapper{
            position: relative;
            overflow: hidden;
            padding-top: calc(250 / 370 * 100%);
            border-radius: 20px;
            cursor: pointer;
            img{
              position: absolute;
              top: 0;
              left: 0;
              width: 100%;
              height: 100%;
              object-fit: cover;
              transform: scale(1);
              transition: transform 0.5s ease-in-out;
            }
            &:hover{
              img{
                transform: scale(1.03);
                transition: transform 0.5s ease-in-out;
              }
            }
          }

          &:last-child{
            margin-bottom: 0;
          }
          &:nth-last-child(2){
            margin-bottom: 0;
          }
        }
      }
    }


    @media(max-width: 767px){
      &__content{
        .image-group{
          &__single{
            &:last-child{
              margin-bottom: 0px;
            }
            &:nth-last-child(2){
              margin-bottom: 20px;
            }
          }
        }
      }
    }
  }
`;

export default MyComponent;
